@@ -1823,7 +1823,7 @@ void Playlist::slotUpdateColumnWidths()
     int usedWidth = 0;
 
     // Now set the actual column widths.  If the weighted widths are all greater
-    // than the minimum widths, just use those, otherwise use the "reajusted
+    // than the minimum widths, just use those, otherwise use the "readjusted
     // weighted width".
 
     foreach(int column, visibleColumns) {
@@ -1868,7 +1868,7 @@ void Playlist::slotShowRMBMenu(const QPoint &point)
 
         m_rmbMenu = new QMenu(this);
 
-        m_rmbMenu->addAction(SmallIcon("go-jump-today"),
+        m_rmbMenu->addAction(QIcon::fromTheme("go-jump-today"),
             i18n("Add to Play Queue"), this, SLOT(slotAddToUpcoming()));
         m_rmbMenu->addSeparator();
 
@@ -1897,7 +1897,9 @@ void Playlist::slotShowRMBMenu(const QPoint &point)
         m_rmbMenu->addSeparator();
 
         m_rmbMenu->addAction(
-            SmallIcon("folder-new"), i18n("Create Playlist From Selected Items..."), this, SLOT(slotCreateGroup()));
+            QIcon::fromTheme("folder-new"),
+            i18n("Create Playlist From Selected Items..."),
+            this, SLOT(slotCreateGroup()));
     }
 
     // Ignore any columns added by subclasses.
