@@ -19,15 +19,14 @@
 
 #include "playlistcollection.h"
 
-#include <k3listview.h>
-
 #include <QHash>
+#include <QTreeWidget>
 
 class Playlist;
 class PlaylistItem;
 class ViewMode;
 
-class KMenu;
+class QMenu;
 
 template<class T>
 class QList;
@@ -39,7 +38,7 @@ typedef QList<Playlist *> PlaylistList;
  * JuK's main widget (PlaylistSplitter).
  */
 
-class PlaylistBox : public K3ListView, public PlaylistCollection
+class PlaylistBox : public QTreeWidget, public PlaylistCollection
 {
     Q_OBJECT
 
@@ -92,19 +91,15 @@ private:
     void readConfig();
     void saveConfig();
 
-    virtual void decode(const QMimeData *s, Item *item);
-    virtual void contentsDropEvent(QDropEvent *e);
-    virtual void contentsDragMoveEvent(QDragMoveEvent *e);
-    virtual void contentsDragLeaveEvent(QDragLeaveEvent *e);
-    virtual void contentsMousePressEvent(QMouseEvent *e);
-    virtual void contentsMouseReleaseEvent(QMouseEvent *e);
+    virtual void mousePressEvent(QMouseEvent *e);
+    virtual void mouseReleaseEvent(QMouseEvent *e);
     virtual void keyPressEvent(QKeyEvent *e);
     virtual void keyReleaseEvent(QKeyEvent *e);
 
     // selectedItems already used for something different
 
     ItemList selectedBoxItems() const;
-    void setSingleItem(Q3ListViewItem *item);
+    void setSingleItem(QTreeWidgetItem *item);
 
     void setupItem(Item *item);
     void setupUpcomingPlaylist();
@@ -117,8 +112,8 @@ private slots:
      * the signal as currentChanged(Item *).
      */
     void slotPlaylistChanged();
-    void slotDoubleClicked(Q3ListViewItem *);
-    void slotShowContextMenu(Q3ListViewItem *, const QPoint &point, int);
+    void slotDoubleClicked(QTreeWidgetItem *);
+    void slotShowContextMenu(const QPoint &point);
     void slotSetViewMode(int index);
     void slotSavePlaylists();
     void slotShowDropTarget();
@@ -132,11 +127,10 @@ private slots:
     void slotLoadCachedPlaylists();
 
 private:
-    KMenu *m_contextMenu;
+    QMenu *m_contextMenu;
     QHash<Playlist *, Item*> m_playlistDict;
     int m_viewModeIndex;
     QList<ViewMode *> m_viewModes;
-    KAction *m_k3bAction;
     bool m_hasSelection;
     bool m_doingMultiSelect;
     Item *m_dropItem;
@@ -144,9 +138,10 @@ private:
     QTimer *m_savePlaylistTimer;
 };
 
-class PlaylistBox::Item : public QObject, public K3ListViewItem, public PlaylistObserver
+class PlaylistBox::Item : public QObject, public QTreeWidgetItem, public PlaylistObserver
 {
     friend class PlaylistBox;
+    friend class PlaylistSplitter;
     friend class ViewMode;
     friend class CompactViewMode;
     friend class TreeViewMode;
@@ -165,17 +160,17 @@ protected:
     Item(Item *parent, const QString &icon, const QString &text, Playlist *l = 0);
 
     Playlist *playlist() const { return m_playlist; }
-    PlaylistBox *listView() const { return static_cast<PlaylistBox *>(K3ListViewItem::listView()); }
+    PlaylistBox *listView() const { return static_cast<PlaylistBox *>(QTreeWidgetItem::treeWidget()); }
     QString iconName() const { return m_iconName; }
     QString text() const { return m_text; }
     void setSortedFirst(bool first = true) { m_sortedFirst = first; }
 
-    virtual int compare(Q3ListViewItem *i, int col, bool) const;
-    virtual void paintCell(QPainter *p, const QColorGroup &colorGroup, int column, int width, int align);
-    virtual void paintFocus(QPainter *, const QColorGroup &, const QRect &) {}
+    virtual int compare(QTreeWidgetItem *i, int col, bool) const;
+    /*virtual void paintCell(QPainter *p, const QColorGroup &colorGroup, int column, int width, int align);
+    virtual void paintFocus(QPainter *, const QColorGroup &, const QRect &) {}*/
     virtual void setText(int column, const QString &text);
 
-    virtual QString text(int column) const { return K3ListViewItem::text(column); }
+    virtual QString text(int column) const { return QTreeWidgetItem::text(column); }
 
     virtual void setup();
 
@@ -186,10 +181,10 @@ protected:
     // Reimplemented from PlaylistObserver
     //
 
-    virtual void updateCurrent();
+    virtual void playingItemHasChanged() Q_DECL_FINAL;
 
     // Used to post a timer in PlaylistBox to save playlists.
-    virtual void updateData();
+    virtual void playlistItemDataHasChanged() Q_DECL_FINAL;
 
 
 protected slots:
