@@ -96,7 +96,6 @@ public:
     void setFile(const QString &file);
     FileHandle file() const;
 
-    virtual const QPixmap *pixmap(int column) const;
     virtual QString text(int column) const;
     virtual void setText(int column, const QString &text);
 
@@ -151,7 +150,7 @@ public:
     PlaylistItem *itemAbove() { return static_cast<PlaylistItem *>(treeWidget()->itemAbove(this)); }
 
     /**
-     * Returns a reference to the list of the currnetly playing items, with the
+     * Returns a reference to the list of the currently playing items, with the
      * first being the "master" item (i.e. the item from which the next track is
      * chosen).
      */
@@ -166,7 +165,7 @@ protected:
     PlaylistItem(CollectionListItem *item, Playlist *parent, QTreeWidgetItem *after);
 
     /**
-     * This is the constructor that shold be used by subclasses.
+     * This is the constructor that should be used by subclasses.
      */
     PlaylistItem(CollectionList *parent);
 
